# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags/protobuf/graph.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featureflags/protobuf/graph.proto',
  package='featureflags.graph',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!featureflags/protobuf/graph.proto\x12\x12\x66\x65\x61tureflags.graph\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"h\n\x03Ref\x12\x11\n\x07Project\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x46lag\x18\x02 \x01(\tH\x00\x12\x13\n\tCondition\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x43heck\x18\x04 \x01(\tH\x00\x12\x12\n\x08Variable\x18\x05 \x01(\tH\x00\x42\x04\n\x02to\"\x14\n\x03Set\x12\r\n\x05items\x18\x01 \x03(\t\"\x9e\x01\n\x08Variable\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12/\n\x04type\x18\x03 \x01(\x0e\x32!.featureflags.graph.Variable.Type\"G\n\x04Type\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\n\n\x06STRING\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\x07\n\x03SET\x10\x04\"\xd3\x03\n\x05\x43heck\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x08variable\x18\x02 \x01(\x0b\x32\x17.featureflags.graph.Ref\x12\x34\n\x08operator\x18\x03 \x01(\x0e\x32\".featureflags.graph.Check.Operator\x12\x16\n\x0cvalue_string\x18\x04 \x01(\tH\x00\x12\x16\n\x0cvalue_number\x18\x05 \x01(\x01H\x00\x12\x35\n\x0fvalue_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12,\n\tvalue_set\x18\x07 \x01(\x0b\x32\x17.featureflags.graph.SetH\x00\"\xbf\x01\n\x08Operator\x12\x0f\n\x0b__DEFAULT__\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\r\n\tLESS_THAN\x10\x02\x12\x11\n\rLESS_OR_EQUAL\x10\x03\x12\x10\n\x0cGREATER_THAN\x10\x04\x12\x14\n\x10GREATER_OR_EQUAL\x10\x05\x12\x0c\n\x08\x43ONTAINS\x10\x06\x12\x0b\n\x07PERCENT\x10\x07\x12\n\n\x06REGEXP\x10\x08\x12\x0c\n\x08WILDCARD\x10\t\x12\n\n\x06SUBSET\x10\n\x12\x0c\n\x08SUPERSET\x10\x0b\x42\x06\n\x04kind\"@\n\tCondition\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x06\x63hecks\x18\x02 \x03(\x0b\x32\x17.featureflags.graph.Ref\"\xd4\x01\n\x04\x46lag\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x07project\x18\x03 \x01(\x0b\x32\x17.featureflags.graph.Ref\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\nconditions\x18\x05 \x03(\x0b\x32\x17.featureflags.graph.Ref\x12.\n\noverridden\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"`\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\r\x12*\n\tvariables\x18\x03 \x03(\x0b\x32\x17.featureflags.graph.Ref\"\xc6\x01\n\x04Root\x12%\n\x04\x66lag\x18\x01 \x01(\x0b\x32\x17.featureflags.graph.Ref\x12&\n\x05\x66lags\x18\x02 \x03(\x0b\x32\x17.featureflags.graph.Ref\x12)\n\x08projects\x18\x03 \x03(\x0b\x32\x17.featureflags.graph.Ref\x12\x15\n\rauthenticated\x18\x05 \x01(\x08\x12-\n\x0c\x66lags_by_ids\x18\x06 \x03(\x0b\x32\x17.featureflags.graph.Ref\"\xcb\x05\n\x06Result\x12&\n\x04Root\x18\x01 \x01(\x0b\x32\x18.featureflags.graph.Root\x12\x38\n\x07Project\x18\x02 \x03(\x0b\x32\'.featureflags.graph.Result.ProjectEntry\x12\x32\n\x04\x46lag\x18\x03 \x03(\x0b\x32$.featureflags.graph.Result.FlagEntry\x12<\n\tCondition\x18\x04 \x03(\x0b\x32).featureflags.graph.Result.ConditionEntry\x12\x34\n\x05\x43heck\x18\x05 \x03(\x0b\x32%.featureflags.graph.Result.CheckEntry\x12:\n\x08Variable\x18\x06 \x03(\x0b\x32(.featureflags.graph.Result.VariableEntry\x1aK\n\x0cProjectEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.featureflags.graph.Project:\x02\x38\x01\x1a\x45\n\tFlagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.featureflags.graph.Flag:\x02\x38\x01\x1aO\n\x0e\x43onditionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.featureflags.graph.Condition:\x02\x38\x01\x1aG\n\nCheckEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.featureflags.graph.Check:\x02\x38\x01\x1aM\n\rVariableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.featureflags.graph.Variable:\x02\x38\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_VARIABLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='featureflags.graph.Variable.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='__DEFAULT__', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SET', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=338,
  serialized_end=409,
)
_sym_db.RegisterEnumDescriptor(_VARIABLE_TYPE)

_CHECK_OPERATOR = _descriptor.EnumDescriptor(
  name='Operator',
  full_name='featureflags.graph.Check.Operator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='__DEFAULT__', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_OR_EQUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_OR_EQUAL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCENT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGEXP', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WILDCARD', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUBSET', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUPERSET', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=680,
  serialized_end=871,
)
_sym_db.RegisterEnumDescriptor(_CHECK_OPERATOR)


_REF = _descriptor.Descriptor(
  name='Ref',
  full_name='featureflags.graph.Ref',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Project', full_name='featureflags.graph.Ref.Project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Flag', full_name='featureflags.graph.Ref.Flag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Condition', full_name='featureflags.graph.Ref.Condition', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Check', full_name='featureflags.graph.Ref.Check', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Variable', full_name='featureflags.graph.Ref.Variable', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='to', full_name='featureflags.graph.Ref.to',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=122,
  serialized_end=226,
)


_SET = _descriptor.Descriptor(
  name='Set',
  full_name='featureflags.graph.Set',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='featureflags.graph.Set.items', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=248,
)


_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='featureflags.graph.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Variable.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.graph.Variable.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='featureflags.graph.Variable.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VARIABLE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=409,
)


_CHECK = _descriptor.Descriptor(
  name='Check',
  full_name='featureflags.graph.Check',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Check.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='featureflags.graph.Check.variable', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featureflags.graph.Check.operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_string', full_name='featureflags.graph.Check.value_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_number', full_name='featureflags.graph.Check.value_number', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_timestamp', full_name='featureflags.graph.Check.value_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_set', full_name='featureflags.graph.Check.value_set', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHECK_OPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='featureflags.graph.Check.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=412,
  serialized_end=879,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='featureflags.graph.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Condition.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checks', full_name='featureflags.graph.Condition.checks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=945,
)


_FLAG = _descriptor.Descriptor(
  name='Flag',
  full_name='featureflags.graph.Flag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Flag.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.graph.Flag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='featureflags.graph.Flag.project', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='featureflags.graph.Flag.enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='featureflags.graph.Flag.conditions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overridden', full_name='featureflags.graph.Flag.overridden', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1160,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='featureflags.graph.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featureflags.graph.Project.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.graph.Project.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featureflags.graph.Project.version', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='featureflags.graph.Project.variables', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1258,
)


_ROOT = _descriptor.Descriptor(
  name='Root',
  full_name='featureflags.graph.Root',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag', full_name='featureflags.graph.Root.flag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='featureflags.graph.Root.flags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projects', full_name='featureflags.graph.Root.projects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticated', full_name='featureflags.graph.Root.authenticated', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags_by_ids', full_name='featureflags.graph.Root.flags_by_ids', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1459,
)


_RESULT_PROJECTENTRY = _descriptor.Descriptor(
  name='ProjectEntry',
  full_name='featureflags.graph.Result.ProjectEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.ProjectEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.ProjectEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1798,
  serialized_end=1873,
)

_RESULT_FLAGENTRY = _descriptor.Descriptor(
  name='FlagEntry',
  full_name='featureflags.graph.Result.FlagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.FlagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.FlagEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1944,
)

_RESULT_CONDITIONENTRY = _descriptor.Descriptor(
  name='ConditionEntry',
  full_name='featureflags.graph.Result.ConditionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.ConditionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.ConditionEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1946,
  serialized_end=2025,
)

_RESULT_CHECKENTRY = _descriptor.Descriptor(
  name='CheckEntry',
  full_name='featureflags.graph.Result.CheckEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.CheckEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.CheckEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2098,
)

_RESULT_VARIABLEENTRY = _descriptor.Descriptor(
  name='VariableEntry',
  full_name='featureflags.graph.Result.VariableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featureflags.graph.Result.VariableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featureflags.graph.Result.VariableEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2177,
)

_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='featureflags.graph.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Root', full_name='featureflags.graph.Result.Root', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Project', full_name='featureflags.graph.Result.Project', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Flag', full_name='featureflags.graph.Result.Flag', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Condition', full_name='featureflags.graph.Result.Condition', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Check', full_name='featureflags.graph.Result.Check', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Variable', full_name='featureflags.graph.Result.Variable', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESULT_PROJECTENTRY, _RESULT_FLAGENTRY, _RESULT_CONDITIONENTRY, _RESULT_CHECKENTRY, _RESULT_VARIABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=2177,
)

_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Project'])
_REF.fields_by_name['Project'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Flag'])
_REF.fields_by_name['Flag'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Condition'])
_REF.fields_by_name['Condition'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Check'])
_REF.fields_by_name['Check'].containing_oneof = _REF.oneofs_by_name['to']
_REF.oneofs_by_name['to'].fields.append(
  _REF.fields_by_name['Variable'])
_REF.fields_by_name['Variable'].containing_oneof = _REF.oneofs_by_name['to']
_VARIABLE.fields_by_name['type'].enum_type = _VARIABLE_TYPE
_VARIABLE_TYPE.containing_type = _VARIABLE
_CHECK.fields_by_name['variable'].message_type = _REF
_CHECK.fields_by_name['operator'].enum_type = _CHECK_OPERATOR
_CHECK.fields_by_name['value_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHECK.fields_by_name['value_set'].message_type = _SET
_CHECK_OPERATOR.containing_type = _CHECK
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_string'])
_CHECK.fields_by_name['value_string'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_number'])
_CHECK.fields_by_name['value_number'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_timestamp'])
_CHECK.fields_by_name['value_timestamp'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CHECK.oneofs_by_name['kind'].fields.append(
  _CHECK.fields_by_name['value_set'])
_CHECK.fields_by_name['value_set'].containing_oneof = _CHECK.oneofs_by_name['kind']
_CONDITION.fields_by_name['checks'].message_type = _REF
_FLAG.fields_by_name['project'].message_type = _REF
_FLAG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FLAG.fields_by_name['conditions'].message_type = _REF
_FLAG.fields_by_name['overridden'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PROJECT.fields_by_name['variables'].message_type = _REF
_ROOT.fields_by_name['flag'].message_type = _REF
_ROOT.fields_by_name['flags'].message_type = _REF
_ROOT.fields_by_name['projects'].message_type = _REF
_ROOT.fields_by_name['flags_by_ids'].message_type = _REF
_RESULT_PROJECTENTRY.fields_by_name['value'].message_type = _PROJECT
_RESULT_PROJECTENTRY.containing_type = _RESULT
_RESULT_FLAGENTRY.fields_by_name['value'].message_type = _FLAG
_RESULT_FLAGENTRY.containing_type = _RESULT
_RESULT_CONDITIONENTRY.fields_by_name['value'].message_type = _CONDITION
_RESULT_CONDITIONENTRY.containing_type = _RESULT
_RESULT_CHECKENTRY.fields_by_name['value'].message_type = _CHECK
_RESULT_CHECKENTRY.containing_type = _RESULT
_RESULT_VARIABLEENTRY.fields_by_name['value'].message_type = _VARIABLE
_RESULT_VARIABLEENTRY.containing_type = _RESULT
_RESULT.fields_by_name['Root'].message_type = _ROOT
_RESULT.fields_by_name['Project'].message_type = _RESULT_PROJECTENTRY
_RESULT.fields_by_name['Flag'].message_type = _RESULT_FLAGENTRY
_RESULT.fields_by_name['Condition'].message_type = _RESULT_CONDITIONENTRY
_RESULT.fields_by_name['Check'].message_type = _RESULT_CHECKENTRY
_RESULT.fields_by_name['Variable'].message_type = _RESULT_VARIABLEENTRY
DESCRIPTOR.message_types_by_name['Ref'] = _REF
DESCRIPTOR.message_types_by_name['Set'] = _SET
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['Check'] = _CHECK
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['Flag'] = _FLAG
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['Root'] = _ROOT
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ref = _reflection.GeneratedProtocolMessageType('Ref', (_message.Message,), {
  'DESCRIPTOR' : _REF,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Ref)
  })
_sym_db.RegisterMessage(Ref)

Set = _reflection.GeneratedProtocolMessageType('Set', (_message.Message,), {
  'DESCRIPTOR' : _SET,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Set)
  })
_sym_db.RegisterMessage(Set)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLE,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Variable)
  })
_sym_db.RegisterMessage(Variable)

Check = _reflection.GeneratedProtocolMessageType('Check', (_message.Message,), {
  'DESCRIPTOR' : _CHECK,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Check)
  })
_sym_db.RegisterMessage(Check)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Condition)
  })
_sym_db.RegisterMessage(Condition)

Flag = _reflection.GeneratedProtocolMessageType('Flag', (_message.Message,), {
  'DESCRIPTOR' : _FLAG,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Flag)
  })
_sym_db.RegisterMessage(Flag)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Project)
  })
_sym_db.RegisterMessage(Project)

Root = _reflection.GeneratedProtocolMessageType('Root', (_message.Message,), {
  'DESCRIPTOR' : _ROOT,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Root)
  })
_sym_db.RegisterMessage(Root)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {

  'ProjectEntry' : _reflection.GeneratedProtocolMessageType('ProjectEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_PROJECTENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.ProjectEntry)
    })
  ,

  'FlagEntry' : _reflection.GeneratedProtocolMessageType('FlagEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_FLAGENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.FlagEntry)
    })
  ,

  'ConditionEntry' : _reflection.GeneratedProtocolMessageType('ConditionEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_CONDITIONENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.ConditionEntry)
    })
  ,

  'CheckEntry' : _reflection.GeneratedProtocolMessageType('CheckEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_CHECKENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.CheckEntry)
    })
  ,

  'VariableEntry' : _reflection.GeneratedProtocolMessageType('VariableEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESULT_VARIABLEENTRY,
    '__module__' : 'featureflags.protobuf.graph_pb2'
    # @@protoc_insertion_point(class_scope:featureflags.graph.Result.VariableEntry)
    })
  ,
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'featureflags.protobuf.graph_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.graph.Result)
  })
_sym_db.RegisterMessage(Result)
_sym_db.RegisterMessage(Result.ProjectEntry)
_sym_db.RegisterMessage(Result.FlagEntry)
_sym_db.RegisterMessage(Result.ConditionEntry)
_sym_db.RegisterMessage(Result.CheckEntry)
_sym_db.RegisterMessage(Result.VariableEntry)


_RESULT_PROJECTENTRY._options = None
_RESULT_FLAGENTRY._options = None
_RESULT_CONDITIONENTRY._options = None
_RESULT_CHECKENTRY._options = None
_RESULT_VARIABLEENTRY._options = None
# @@protoc_insertion_point(module_scope)
