# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureflags/protobuf/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hiku.protobuf import query_pb2 as hiku_dot_protobuf_dot_query__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from featureflags.protobuf import graph_pb2 as featureflags_dot_protobuf_dot_graph__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featureflags/protobuf/service.proto',
  package='featureflags.service',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#featureflags/protobuf/service.proto\x12\x14\x66\x65\x61tureflags.service\x1a\x19hiku/protobuf/query.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!featureflags/protobuf/graph.proto\"I\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.featureflags.graph.Variable.Type\"w\n\tFlagUsage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r\"\xc6\x01\n\x0f\x45xchangeRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x31\n\tvariables\x18\x03 \x03(\x0b\x32\x1e.featureflags.service.Variable\x12\x34\n\x0b\x66lags_usage\x18\x04 \x03(\x0b\x32\x1f.featureflags.service.FlagUsage\x12(\n\x05query\x18\x05 \x01(\x0b\x32\x19.hiku.protobuf.query.Node\"L\n\rExchangeReply\x12\x0f\n\x07version\x18\x01 \x01(\r\x12*\n\x06result\x18\x02 \x01(\x0b\x32\x1a.featureflags.graph.Result\"\x7f\n\x0eStoreStatsTask\x12\x0f\n\x07\x66lag_id\x18\x01 \x01(\t\x12,\n\x08interval\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enegative_count\x18\x03 \x01(\r\x12\x16\n\x0epositive_count\x18\x04 \x01(\r2\xe5\x02\n\x0c\x46\x65\x61tureFlags\x12[\n\x08\x65xchange\x12%.featureflags.service.ExchangeRequest\x1a#.featureflags.service.ExchangeReply\"\x03\x88\x02\x01\x12X\n\x08\x45xchange\x12%.featureflags.service.ExchangeRequest\x1a#.featureflags.service.ExchangeReply\"\x00\x12P\n\x0bstore_stats\x12$.featureflags.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x03\x88\x02\x01\x12L\n\nStoreStats\x12$.featureflags.service.StoreStatsTask\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[hiku_dot_protobuf_dot_query__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,featureflags_dot_protobuf_dot_graph__pb2.DESCRIPTOR,])




_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='featureflags.service.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.service.Variable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='featureflags.service.Variable.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=258,
)


_FLAGUSAGE = _descriptor.Descriptor(
  name='FlagUsage',
  full_name='featureflags.service.FlagUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featureflags.service.FlagUsage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='featureflags.service.FlagUsage.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_count', full_name='featureflags.service.FlagUsage.negative_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positive_count', full_name='featureflags.service.FlagUsage.positive_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=379,
)


_EXCHANGEREQUEST = _descriptor.Descriptor(
  name='ExchangeRequest',
  full_name='featureflags.service.ExchangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featureflags.service.ExchangeRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featureflags.service.ExchangeRequest.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='featureflags.service.ExchangeRequest.variables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags_usage', full_name='featureflags.service.ExchangeRequest.flags_usage', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='featureflags.service.ExchangeRequest.query', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=580,
)


_EXCHANGEREPLY = _descriptor.Descriptor(
  name='ExchangeReply',
  full_name='featureflags.service.ExchangeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='featureflags.service.ExchangeReply.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='featureflags.service.ExchangeReply.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=658,
)


_STORESTATSTASK = _descriptor.Descriptor(
  name='StoreStatsTask',
  full_name='featureflags.service.StoreStatsTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag_id', full_name='featureflags.service.StoreStatsTask.flag_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='featureflags.service.StoreStatsTask.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_count', full_name='featureflags.service.StoreStatsTask.negative_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positive_count', full_name='featureflags.service.StoreStatsTask.positive_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=787,
)

_VARIABLE.fields_by_name['type'].enum_type = featureflags_dot_protobuf_dot_graph__pb2._VARIABLE_TYPE
_FLAGUSAGE.fields_by_name['interval'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXCHANGEREQUEST.fields_by_name['variables'].message_type = _VARIABLE
_EXCHANGEREQUEST.fields_by_name['flags_usage'].message_type = _FLAGUSAGE
_EXCHANGEREQUEST.fields_by_name['query'].message_type = hiku_dot_protobuf_dot_query__pb2._NODE
_EXCHANGEREPLY.fields_by_name['result'].message_type = featureflags_dot_protobuf_dot_graph__pb2._RESULT
_STORESTATSTASK.fields_by_name['interval'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['FlagUsage'] = _FLAGUSAGE
DESCRIPTOR.message_types_by_name['ExchangeRequest'] = _EXCHANGEREQUEST
DESCRIPTOR.message_types_by_name['ExchangeReply'] = _EXCHANGEREPLY
DESCRIPTOR.message_types_by_name['StoreStatsTask'] = _STORESTATSTASK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLE,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.Variable)
  })
_sym_db.RegisterMessage(Variable)

FlagUsage = _reflection.GeneratedProtocolMessageType('FlagUsage', (_message.Message,), {
  'DESCRIPTOR' : _FLAGUSAGE,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.FlagUsage)
  })
_sym_db.RegisterMessage(FlagUsage)

ExchangeRequest = _reflection.GeneratedProtocolMessageType('ExchangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEREQUEST,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.ExchangeRequest)
  })
_sym_db.RegisterMessage(ExchangeRequest)

ExchangeReply = _reflection.GeneratedProtocolMessageType('ExchangeReply', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEREPLY,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.ExchangeReply)
  })
_sym_db.RegisterMessage(ExchangeReply)

StoreStatsTask = _reflection.GeneratedProtocolMessageType('StoreStatsTask', (_message.Message,), {
  'DESCRIPTOR' : _STORESTATSTASK,
  '__module__' : 'featureflags.protobuf.service_pb2'
  # @@protoc_insertion_point(class_scope:featureflags.service.StoreStatsTask)
  })
_sym_db.RegisterMessage(StoreStatsTask)



_FEATUREFLAGS = _descriptor.ServiceDescriptor(
  name='FeatureFlags',
  full_name='featureflags.service.FeatureFlags',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=790,
  serialized_end=1147,
  methods=[
  _descriptor.MethodDescriptor(
    name='exchange',
    full_name='featureflags.service.FeatureFlags.exchange',
    index=0,
    containing_service=None,
    input_type=_EXCHANGEREQUEST,
    output_type=_EXCHANGEREPLY,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Exchange',
    full_name='featureflags.service.FeatureFlags.Exchange',
    index=1,
    containing_service=None,
    input_type=_EXCHANGEREQUEST,
    output_type=_EXCHANGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='store_stats',
    full_name='featureflags.service.FeatureFlags.store_stats',
    index=2,
    containing_service=None,
    input_type=_STORESTATSTASK,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StoreStats',
    full_name='featureflags.service.FeatureFlags.StoreStats',
    index=3,
    containing_service=None,
    input_type=_STORESTATSTASK,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATUREFLAGS)

DESCRIPTOR.services_by_name['FeatureFlags'] = _FEATUREFLAGS

# @@protoc_insertion_point(module_scope)
