from setuptools import setup, find_packages

setup(
    name='evo-featureflags-protobuf',
    version='0.2.1',
    description='Protocol Buffers stub files for feature flags service',
    author='Vladimir Magamedov',
    author_email='vladimir@magamedov.com',
    packages=find_packages(),
    install_requires=[],
)
